@@ -520,14 +520,14 @@ class ParametersLEDET:
     def checkHeFraction(self, Groups):
         k = self.Inputs.overwrite_f_externalVoids_inGroup
         k2 = self.Inputs.overwrite_f_internalVoids_inGroup
-        if k:
+        if len(k) > 0:
             if len(k) != len(k2):
                 print("Helium section was set but is corrupted.")
                 return False
             if len(k) != Groups:
                 print("Helium section was set but is wrong length.")
                 return False
-        elif k2:
+        elif len(k2) > 0:
             print("Helium section was set but is corrupted.")
             return False
         return True
