@@ -382,13 +382,16 @@ class ParametersCOSIM:
 
         struct_total = []
         for n in range(0, N_LEDET):
-            if n== QuenchMagnet and QuenchMagnet != 0:
+            if n+1== QuenchMagnet and QuenchMagnet != 0:
                 quench = '_QUENCH'
             else:
                 quench = ''
             if DistinctMagnets != 1:
                 DM = n+1
                 M_add = "M"+str(DM)+'_'
+            elif n == QuenchMagnet and QuenchMagnet != 0:
+                DM = 1+QuenchMagnet
+                M_add = ''
             else:
                 DM = 1
                 M_add = ''
